import java.awt.BorderLayout;
import java.awt.Color;
import java.util.Arrays;

import javax.swing.JFrame;
import javax.swing.SwingUtilities;

import com.mindfusion.charting.FunctionSeries;
import com.mindfusion.charting.GridType;
import com.mindfusion.charting.swing.LineChart;
import com.mindfusion.drawing.Brushes;
import com.mindfusion.drawing.DashStyle;
import com.mindfusion.drawing.SolidBrush;


public class MainWindow extends JFrame
{
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	public static void main(String[] args)
	{
		SwingUtilities.invokeLater(new Runnable()
		{
			public void run()
			{
				try
				{
					new MainWindow().setVisible(true);
				}
				catch (Exception exp)
				{
				}
			}
		});
	}
	
	protected MainWindow()
	{
		setDefaultCloseOperation(EXIT_ON_CLOSE);
		setSize(650, 400);
		setTitle("Java Swing Library for Charts and Gauges: FunctionSeries");		
		//add the chart to the ContentPane
		getContentPane().add(initializeChart(), BorderLayout.CENTER);
	}
	
	private LineChart initializeChart()
	{
		LineChart lineChart = new LineChart();	
		
		lineChart.getXAxis().setMinValue(-5.0);
		lineChart.getXAxis().setMaxValue(5.0);
		lineChart.getXAxis().setInterval(0.5);
		lineChart.getXAxis().setOrigin(0.0);
		lineChart.getXAxis().setTitle("X-axis");
		
		lineChart.getYAxis().setMaxValue(30.0);
		lineChart.getYAxis().setMinValue(-30.0);
		lineChart.getYAxis().setTitle("Y-axis");
	
		//specifying color and stroke for the axes
		lineChart.getTheme().setAxisStroke(new SolidBrush(new Color(190, 190, 190)));
		lineChart.getTheme().setAxisStrokeThickness(1.0);
		
		//styling the legend
		lineChart.getLegendRenderer().setShowTitle(false);
		lineChart.getTheme().setDataLabelsFontSize(12);		
		
		//styling the grid
		lineChart.setGridType(GridType.Crossed);
		lineChart.getTheme().setGridLineColor(new Color(192, 192, 192));
		lineChart.getTheme().setGridLineStyle(DashStyle.Dot);
		
		//setting the chart colors
		lineChart.getTheme().setHighlightStroke(Brushes.Orange);
		lineChart.getTheme().setCommonSeriesStrokes(
				Arrays.asList(
					new SolidBrush( new Color (90, 116, 68 )),
					new SolidBrush( new Color (70, 105, 125))));
		lineChart.getTheme().setCommonSeriesFills(
				Arrays.asList(
					new SolidBrush( new Color (90, 116, 68 )),
					new SolidBrush( new Color (70, 105, 125))));
		lineChart.getTheme().setCommonSeriesStrokeThicknesses(
				Arrays.asList(3.0));		
		
		FunctionSeries series1;
		FunctionSeries series2;	
		
		try
		{
			
			series1 = new FunctionSeries(
				"3*x*x+2*x+2", 1000, -5, 5 );
			series1.setTitle("Quadratic equation: 3*x*x+2*x+2");
			lineChart.getSeries().add(series1);
			
			//mean value is -2
			series2 = new FunctionSeries(
					"-3*x*x+4*x+1", 1000, -5, 5);
				series2.setTitle("Quadratic equation: -3*x*x+4*x+1");
				lineChart.getSeries().add(series2);
				
			
			
		}
		catch (Exception e)
		{
			// could not parse the expression
			e.printStackTrace();
		}
		
		return lineChart;
	}
	

}
